aboutsummaryrefslogtreecommitdiff
path: root/src/Watcher/afk.py
diff options
context:
space:
mode:
authorLibravatar Waishnav <[email protected]>2022-09-17 06:39:45 +0530
committerLibravatar Waishnav <[email protected]>2022-09-17 06:39:45 +0530
commitf0636d1ac0201686b22f252f3b7eaba7879553b6 (patch)
treec9853a75734ca2803623a83d295659d37bafdf35 /src/Watcher/afk.py
parent9fd05fa5f70164aaa7df70bdf4b6b467f7108f22 (diff)
downloadshopno-os-log-sync-f0636d1ac0201686b22f252f3b7eaba7879553b6.tar.gz
shopno-os-log-sync-f0636d1ac0201686b22f252f3b7eaba7879553b6.zip
compensating error value changed
Diffstat (limited to '')
-rwxr-xr-xsrc/Watcher/afk.py2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/Watcher/afk.py b/src/Watcher/afk.py
index 41f8fe9..3d92068 100755
--- a/src/Watcher/afk.py
+++ b/src/Watcher/afk.py
@@ -15,7 +15,7 @@ def returned_from_afk(afk_active, timeout):
return has_returned
def is_afk(timeout):
- timeout = timeout * 60 * 1000 - 200 # minimizing 200 milisec error
+ timeout = timeout * 60 * 1000 - 100 # minimizing 100 milisec error
#If the AFK feature is installed
time_since_last_input = int(os.popen("xprintidle").read()[:-1])
if (time_since_last_input > timeout):